/*
 * Example of a GUI in Processing that sends OSC messages
 *
 * 2012, Marc Groenewegen, Hogeschool voor de Kunsten Utrecht
 *
 * oscP5 and controlP5 created by Andreas Schlegel
 * oscP5 -- http://www.sojamo.de/oscP5
 * controlP5 -- http://www.sojamo.de/libraries/controlP5/
 */
 
import oscP5.*;
import netP5.*;
import controlP5.*;

Slider s1,s2;

OscP5 oscP5;
NetAddress myRemoteLocation;

ControlP5 controlP5;

void setup()
{
  size(400,400);
  frameRate(25);

  // start oscP5 and listen for incoming messages at port 12001
  oscP5 = new OscP5(this,12001);

  // use the following IP/port combination to send messages to
  myRemoteLocation = new NetAddress("localhost",12000);
  
  controlP5 = new ControlP5(this);
  // add a vertical slider
  s1 = controlP5.addSlider("slider1",0,200,0,10,10,10,100);
  s2 = controlP5.addSlider("slider2",0,200,0,50,10,10,100);
} // setup()


/*
 * Draw loop must be present for this program to work, even though we don't
 * do a lot of magic here
 */
void draw()
{
  background(0);  
}


/*
 * The function oscEvent is triggered when a message comes in
 */
void oscEvent(OscMessage theOscMessage)
{
  /* print the address pattern and the typetag of the received OscMessage */
  print("Received an osc message.");
  print("Message name: "+theOscMessage.addrPattern());
  println("type: "+theOscMessage.typetag());
}

/*
 * Pressing a key moves the sliders to a predefined value
 */
void keyPressed()
{
  s1.setValue(100);
  s2.setValue(100);
}

/*
 * For every GUI element, a function with a corresponding name is created
 * that gets triggered when the status of the GUI element changes, e.g.
 * when a slider is being moved or a button is pressed
 */
void slider1(float sliderValue)
{
    OscMessage myMessage = new OscMessage("/volume");
    myMessage.add(sliderValue); // add a number
    oscP5.send(myMessage, myRemoteLocation); 
}


void slider2(float sliderValue)
{
    OscMessage myMessage = new OscMessage("/pitch");
    myMessage.add(sliderValue); // add a number
    oscP5.send(myMessage, myRemoteLocation); 
}

