/*
 * Example of a server in Processing that receives OSC messages and can
 * send a reply
 *
 * 2012, Marc Groenewegen, Hogeschool voor de Kunsten Utrecht
 *
 * oscP5 and controlP5 created by Andreas Schlegel
 * oscP5 -- http://www.sojamo.de/oscP5
 * controlP5 -- http://www.sojamo.de/libraries/controlP5/
 */
 
import oscP5.*;
import netP5.*;
  
OscP5 oscP5;
NetAddress myRemoteLocation;

float x,y;

void setup()
{
  size(400,300);
  x=width/2;
  y=height/2;
  frameRate(25);

  // start oscP5 and listen for incoming messages at port 12000
  oscP5 = new OscP5(this,12000);
  
  // use the following IP/port combination to send messages to
  myRemoteLocation = new NetAddress("localhost",12001);
} // setup()


/*
 * Draw loop must be present for this program to work, even though we don't
 * do a lot of magic here
 */
void draw()
{
  background(0);
  fill(200,200,0);
  ellipse(x,y,30,30);
}


/*
 * The function oscEvent is triggered when a message comes in
 */
void oscEvent(OscMessage theOscMessage)
{
  // Show some info about the received message
  print("Received an osc message");
  String msgType =  theOscMessage.addrPattern();
  float msgValue = theOscMessage.get(0).floatValue(); // assuming a float

  print("Message name: " + msgType);
  print(" value: " + msgValue);
  println(" type: "+theOscMessage.typetag());

  // handle a certain type of message
  if(msgType.equals("/volume"))
  {
    x=msgValue; // move the ellipse
  }

  // Send a reply to the client to say that we received the message
  OscMessage myMessage = new OscMessage("/ack");
  myMessage.add(0);
    oscP5.send(myMessage, myRemoteLocation); 
} // oscEvent()

